@@ -8,13 +8,13 @@ from mezzanine.pages.models import Page
 
 
 FIELD_MAPPING = (
-    (1, "Check-box", "BooleanField"),
-    (2, "Text", "CharField"),
+    (1, "Text", "CharField"),
     (3, "Email", "EmailField"),
-    (4, "Date", "DateField"),
-    (5, "Date/time", "DateTimeField"),
+    (2, "Check-box", "BooleanField"),
     (6, "Drop-down", "ChoiceField"),
     (7, "Multi-select", "MultipleChoiceField"),
+    (4, "Date", "DateField"),
+    (5, "Date/time", "DateTimeField"),
 )
 
 FIELD_CHOICES = [f[:2] for f in FIELD_MAPPING]
@@ -30,10 +30,6 @@ class Form(Page):
     class Meta:
         verbose_name = _("Form")
         verbose_name_plural = _("Forms")
-        
-    @models.permalink
-    def get_absolute_url(self):
-        return ("form_detail", (), {"slug": self.slug})
 
 class Field(Orderable):
     
